@@ -26,6 +26,11 @@
 #include "dialog_import_csv_progress.h"
 #include <glom/libglom/appstate.h>
 
+#include <glom/libglom/connectionpool.h>
+#include <glom/libglom/connectionpool_backends/postgres_central.h>
+#include <glom/libglom/connectionpool_backends/postgres_self.h>
+#include <glom/libglom/connectionpool_backends/sqlite.h>
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 #include "mode_design/users/dialog_groups_list.h"
 #include "dialog_database_preferences.h"
@@ -65,7 +70,6 @@ namespace Glom
 
 Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
 : PlaceHolder(cobject, refGlade),
-  m_pLabel_Name(0),
   m_pLabel_Table(0),
   m_box_footer(0),
   m_pLabel_Mode(0),
@@ -95,7 +99,6 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade:
   m_pDialogConnection(0)
 {
   //Load widgets from glade file:
-  refGlade->get_widget("label_name", m_pLabel_Name);
   refGlade->get_widget("label_table_name", m_pLabel_Table);
 
   refGlade->get_widget("hbox_footer", m_box_footer);
@@ -129,8 +132,6 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade:
 
   refGlade->get_widget_derived("vbox_mode", m_pBox_Mode);
 
-  //m_pLabel_Mode->set_text(_("No database selected.\n Use the Navigation menu, or open a previous Glom document."));
-
   m_Mode = MODE_None;
   m_Mode_Previous = MODE_None;
 
@@ -148,14 +149,6 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade:
   add_view(&m_Notebook_Find); //Also a composite view.
 
   on_userlevel_changed(AppState::USERLEVEL_OPERATOR); //A default to show before a document is created or loaded.
-
-#ifdef GLOM_ENABLE_MAEMO
-  // Don't show the document name on maemo. The label is on top of the window,
-  // and the document name is already shown in the window title (note that
-  // there is not even a menu between them as in the non-maemo version). This
-  // looks a bit strange and takes vertical screen space.
-  m_pLabel_Name->hide();
-#endif
 }
 
 Frame_Glom::~Frame_Glom()
@@ -236,7 +229,7 @@ void Frame_Glom::set_databases_selected(const Glib::ustring& strName)
 
   get_document()->set_connection_database(strName);
 
-  show_system_name();
+  //show_system_name();
 
   do_menu_Navigate_Table(true /* open default */);
 }
@@ -422,7 +415,7 @@ void Frame_Glom::show_table(const Glib::ustring& table_name, const Gnome::Gda::V
       case(MODE_Find):
       {
         strMode = _("Find");
-        m_Notebook_Find.init_db_details(m_table_name);
+        m_Notebook_Find.init_db_details(m_table_name, get_document()->get_active_layout_platform());
         set_mode_widget(m_Notebook_Find);
         break;
       }
@@ -455,8 +448,16 @@ void Frame_Glom::on_menu_userlevel_Developer(const Glib::RefPtr<Gtk::RadioAction
     if(document)
     {
       //Check whether the current user has developer privileges:
-      const ConnectionPool* connection_pool = ConnectionPool::get_instance();
-      bool test = Privs::get_user_is_in_group(connection_pool->get_user(), GLOM_STANDARD_GROUP_NAME_DEVELOPER);
+      ConnectionPool* connection_pool = ConnectionPool::get_instance();
+      sharedptr<SharedConnection> sharedconnection = connection_pool->connect();
+
+      // Default to true; if we don't support users, we always have
+      // priviliges to change things in developer mode.
+      bool test = true;
+
+      if(sharedconnection && sharedconnection->get_gda_connection()->supports_feature(Gnome::Gda::CONNECTION_FEATURE_USERS))
+        Privs::get_user_is_in_group(connection_pool->get_user(), GLOM_STANDARD_GROUP_NAME_DEVELOPER);
+
       if(test)
       {
         std::cout << "DEBUG: User=" << connection_pool->get_user() << " _is_ in the developer group on the server." << std::endl;
@@ -532,7 +533,11 @@ void Frame_Glom::on_menu_file_export()
 {
   //Start with a sequence based on the Details view:
   //The user can changed this by clicking the button in the FileChooser:
-  Document_Glom::type_list_layout_groups mapGroupSequence =  get_document()->get_data_layout_groups_plus_new_fields("details", m_table_name);
+  Document_Glom* document = get_document();
+  if(!document)
+    return;
+
+  Document_Glom::type_list_layout_groups mapGroupSequence = document->get_data_layout_groups_plus_new_fields("details", m_table_name, document->get_active_layout_platform());
 
   Gtk::Window* pWindowApp = get_app_window();
   g_assert(pWindowApp);
@@ -559,6 +564,7 @@ void Frame_Glom::on_menu_file_export()
     return;
 
   dialog.get_layout_groups(mapGroupSequence);
+  std::cout << "DEBUG 0: mapGroupSequence.size()=" << mapGroupSequence.size() << std::endl;
 
   //const int index_primary_key = fieldsSequence.size() - 1;
 
@@ -579,12 +585,15 @@ void Frame_Glom::export_data_to_string(Glib::ustring& the_string, const FoundSet
   type_vecLayoutFields fieldsSequence = get_table_fields_to_show_for_sequence(found_set.m_table_name, sequence);
 
   if(fieldsSequence.empty())
+  {
+    std::cerr << "Glom: Frame_Glom::export_data_to_string(): No fields in sequence." << std::endl;
     return;
+  }
 
   const Glib::ustring query = Utils::build_sql_select_with_where_clause(found_set.m_table_name, fieldsSequence, found_set.m_where_clause, found_set.m_extra_join, found_set.m_sort_clause, found_set.m_extra_group_by);
 
   //TODO: Lock the database (prevent changes) during export.
-  Glib::RefPtr<Gnome::Gda::DataModel> result = query_execute(query, get_app_window());
+  Glib::RefPtr<Gnome::Gda::DataModel> result = query_execute_select(query);
 
   guint rows_count = 0;
   if(result)
@@ -609,7 +618,7 @@ void Frame_Glom::export_data_to_string(Glib::ustring& the_string, const FoundSet
               row_string += ",";
 
             //Output data in canonical SQL format, ignoring the user's locale, and ignoring the layout formatting:
-            row_string += layout_item->get_full_field_details()->sql(value);
+            row_string += layout_item->get_full_field_details()->sql(value, Field::SQL_FORMAT_POSTGRES);
 
             //if(layout_item->m_field.get_glom_type() == Field::TYPE_IMAGE) //This is too much data.
             //{
@@ -628,12 +637,15 @@ void Frame_Glom::export_data_to_stream(std::ostream& the_stream, const FoundSet&
   type_vecLayoutFields fieldsSequence = get_table_fields_to_show_for_sequence(found_set.m_table_name, sequence);
 
   if(fieldsSequence.empty())
+  {
+    std::cerr << "Glom: Frame_Glom::export_data_to_stream(): No fields in sequence." << std::endl;
     return;
+  }
 
   const Glib::ustring query = Utils::build_sql_select_with_where_clause(found_set.m_table_name, fieldsSequence, found_set.m_where_clause, found_set.m_extra_join, found_set.m_sort_clause, found_set.m_extra_group_by);
-
+ 
   //TODO: Lock the database (prevent changes) during export.
-  Glib::RefPtr<Gnome::Gda::DataModel> result = query_execute(query, get_app_window());
+  Glib::RefPtr<Gnome::Gda::DataModel> result = query_execute_select(query);
 
   guint rows_count = 0;
   if(result)
@@ -658,7 +670,7 @@ void Frame_Glom::export_data_to_stream(std::ostream& the_stream, const FoundSet&
               row_string += ",";
 
             //Output data in canonical SQL format, ignoring the user's locale, and ignoring the layout formatting:
-            row_string += layout_item->get_full_field_details()->sql(value);
+            row_string += layout_item->get_full_field_details()->sql(value, Field::SQL_FORMAT_POSTGRES);
 
             if(layout_item->get_glom_type() == Field::TYPE_IMAGE) //This is too much data.
             {
@@ -690,19 +702,20 @@ void Frame_Glom::on_menu_file_import()
 
     if(file_chooser.run() == Gtk::RESPONSE_ACCEPT)
     {
+      file_chooser.hide();
+
       Dialog_Import_CSV* dialog = 0;
       Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom.glade"), "dialog_import_csv");
       refXml->get_widget_derived("dialog_import_csv", dialog);
       add_view(dialog);
 
-      file_chooser.hide();
-
       dialog->import(file_chooser.get_uri(), m_table_name);
       while(Glom::Utils::dialog_run_with_help(dialog, "dialog_import_csv") == Gtk::RESPONSE_ACCEPT)
       {
         dialog->hide();
+
         Dialog_Import_CSV_Progress* progress_dialog = 0;
-      Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom.glade"), "dialog_import_csv_progress");
+        Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom.glade"), "dialog_import_csv_progress");
         refXml->get_widget_derived("dialog_import_csv_progress", progress_dialog);
         add_view(progress_dialog);
 
@@ -712,6 +725,7 @@ void Frame_Glom::on_menu_file_import()
 
         remove_view(progress_dialog);
         delete progress_dialog;
+        progress_dialog = 0;
 
         // Force update from database so the newly added entries are shown
         show_table_refresh();
@@ -1237,29 +1251,6 @@ void Frame_Glom::set_document(Document_Glom* pDocument)
   }
 }
 
-void Frame_Glom::show_system_name()
-{
-  // Don't show the document name on maemo. The label is on top of the window,
-  // and the document name is already shown in the window title (note that
-  // there is not even a menu between them as in the non-maemo version). This
-  // looks a bit strange and takes unnecessarily vertical screen space.
-#ifndef GLOM_ENABLE_MAEMO
-  const SystemPrefs prefs = get_database_preferences();
-  const Glib::ustring org = prefs.m_org_name;
-  const Glib::ustring name = prefs.m_name;
-
-  Glib::ustring system_name = org;
-  if(!system_name.empty() && !name.empty())
-    system_name += ": ";
-
-  system_name += name;
-
-  m_pLabel_Name->set_text ( Bakery::App_Gtk::util_bold_message(system_name) );
-  m_pLabel_Name->set_use_markup();
-  m_pLabel_Name->show();
-#endif // !GLOM_ENABLE_MAEMO
-}
-
 void Frame_Glom::load_from_document()
 {
   Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
@@ -1289,7 +1280,7 @@ void Frame_Glom::on_menu_developer_database_preferences()
       remove_view(dialog);
       delete dialog;
 
-      show_system_name(); //In case it has changed.
+      //show_system_name(); //In case it has changed.
     }
   }
 
@@ -1453,9 +1444,11 @@ void Frame_Glom::on_menu_developer_reports()
   {
     Utils::get_glade_developer_widget_derived_with_warning("box_reports", m_pBox_Reports);
     m_pDialog_Reports = new Dialog_Glom(m_pBox_Reports);
+    m_pDialog_Reports->set_transient_for(*(get_app_window()));
 
     Utils::get_glade_developer_widget_derived_with_warning("window_report_layout", m_pDialogLayoutReport);
     add_view(m_pDialogLayoutReport);
+    m_pDialogLayoutReport->set_transient_for(*(get_app_window()));
     m_pDialogLayoutReport->signal_hide().connect( sigc::mem_fun(*this, &Frame_Glom::on_dialog_layout_report_hide) );
 
     m_pDialog_Reports->get_vbox()->pack_start(*m_pBox_Reports);
@@ -1562,28 +1555,58 @@ void Frame_Glom::on_developer_dialog_hide()
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
+namespace 
+{
+  void setup_connection_pool_from_document(Document_Glom* document)
+  {
+    ConnectionPool* connection_pool = ConnectionPool::get_instance();
+    switch(document->get_hosting_mode())
+    {
+    case Document_Glom::POSTGRES_SELF_HOSTED:
+      {
+        ConnectionPoolBackends::PostgresSelfHosted* backend = new ConnectionPoolBackends::PostgresSelfHosted;
+        backend->set_self_hosting_data_uri(document->get_connection_self_hosted_directory_uri());
+        connection_pool->set_backend(std::auto_ptr<ConnectionPoolBackend>(backend));
+      }
+      break;
+    case Document_Glom::POSTGRES_CENTRAL_HOSTED:
+      {
+        ConnectionPoolBackends::PostgresCentralHosted* backend = new ConnectionPoolBackends::PostgresCentralHosted;
+        backend->set_host(document->get_connection_server());
+        backend->set_port(document->get_connection_port());
+        backend->set_try_other_ports(document->get_connection_try_other_ports());
+        connection_pool->set_backend(std::auto_ptr<ConnectionPoolBackend>(backend));
+      }
+
+      break;
+    case Document_Glom::SQLITE_HOSTED:
+      {
+        ConnectionPoolBackends::Sqlite* backend = new ConnectionPoolBackends::Sqlite;
+        backend->set_database_directory_uri(document->get_connection_self_hosted_directory_uri());
+        connection_pool->set_backend(std::auto_ptr<ConnectionPoolBackend>(backend));
+      }
+      break;
+    default:
+      g_assert_not_reached();
+      break;
+    }
+
+    // Might be overwritten later when actually attempting a connection:
+    connection_pool->set_user(document->get_connection_user());
+    connection_pool->set_database(document->get_connection_database());
+
+    connection_pool->set_ready_to_connect();
+  }
+}
+
 bool Frame_Glom::connection_request_password_and_choose_new_database_name()
 {
   Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
   if(!document)
     return false;
 
-#ifndef GLOM_ENABLE_CLIENT_ONLY
-  //Give the ConnectionPool the self-hosted file path, 
-  //so that create_self_hosted() can succeed:
   ConnectionPool* connection_pool = ConnectionPool::get_instance();
-
-  // Client only mode does not support self hosting, so there is nothing to do.
-  if(connection_pool && document && document->get_connection_is_self_hosted())
-  {
-    // TODO: sleep, to give postgres time to start?
-    connection_pool->set_self_hosted(document->get_connection_self_hosted_directory_uri());
-  }
-  else
-  {
-    connection_pool->set_self_hosted(std::string());
-  }
-#endif // !GLOM_ENABLE_CLIENT_ONLY
+  setup_connection_pool_from_document(document);
 
   if(!m_pDialogConnection)
   {
@@ -1594,9 +1617,9 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
   //Ask either for the existing username and password to use an existing database server,
   //or ask for a new username and password to specify when creating a new self-hosted database.
   int response = 0;
-#ifndef GLOM_ENABLE_CLIENT_ONLY
-  if(document->get_connection_is_self_hosted())
+  if(document->get_hosting_mode() == Document_Glom::POSTGRES_SELF_HOSTED)
   {
+#ifndef GLOM_ENABLE_CLIENT_ONLY
     Dialog_NewSelfHostedConnection* dialog = 0;
     Glib::RefPtr<Gnome::Glade::Xml> refXml;
 
@@ -1653,25 +1676,9 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
     if(response == Gtk::RESPONSE_OK)
     {
       created = dialog->create_self_hosted();
-      if(created)
-      {
-        const bool test = connection_pool->start_self_hosting(get_app_window());
-        if(!test)
-          return false;
-
-        // Store in document, so these values are actually used when connecting
-        Document_Glom* document = get_document();
-        if(document)
-        {
-          document->set_connection_port(connection_pool->get_port());
-          document->set_connection_try_other_ports(connection_pool->get_try_other_ports());
-        }
-      }
-      else
+      if(!created)
         return false;
 
-      //dialog->create_self_hosted() has already set enough information in the ConnectionPool to allow a connection so we can create the database in the new database cluster:
-     
       //Put the details into m_pDialogConnection too, because that's what we use to connect.
       //This is a bit of a hack:
       m_pDialogConnection->set_self_hosted_user_and_password(connection_pool->get_user(), connection_pool->get_password());
@@ -1682,92 +1689,119 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
     //std::cout << "DEBUG: after dialog->create_self_hosted(). The database cluster should now exist." << std::endl;
 
     if(!created)
-      return false;
-  }
-  else
+      return false; // The user cancelled
+#else
+    // Self-hosted postgres not supported in client only mode
+    g_assert_not_reached();
 #endif // !GLOM_ENABLE_CLIENT_ONLY
+  }
+  else if(document->get_hosting_mode() == Document_Glom::POSTGRES_CENTRAL_HOSTED)
   {
     //Ask for connection details:
     m_pDialogConnection->load_from_document(); //Get good defaults.
     m_pDialogConnection->set_transient_for(*get_app_window());
     response = Glom::Utils::dialog_run_with_help(m_pDialogConnection, "dialog_connection");
     m_pDialogConnection->hide();
-  }
 
-  if(response == Gtk::RESPONSE_OK)
-  {
-    const Glib::ustring database_name = document->get_connection_database();
-
-    //std::cout << "debug: database_name to create=" << database_name << std::endl;
-
-
-    bool keep_trying = true;
-    size_t extra_num = 0;
-    while(keep_trying)
+    if(response == Gtk::RESPONSE_OK)
     {
-      Glib::ustring database_name_possible;
-      if(extra_num == 0)
-        database_name_possible = database_name; //Try the original name first.
-      else
-      {
-        //Create a new database name by appending a number to the original name:
-        char pchExtraNum[10];
-        sprintf(pchExtraNum, "%d", extra_num);
-        database_name_possible = (database_name + pchExtraNum);
-      }
-      ++extra_num;
-
-      m_pDialogConnection->set_database_name(database_name_possible);
-      //std::cout << "debug: possible name=" << database_name_possible << std::endl;
-
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-      try
-      {
-        sharedptr<SharedConnection> sharedconnection = m_pDialogConnection->connect_to_server_with_connection_settings();
-        //If no exception was thrown then the database exists.
-        //But we are looking for an unused database name, so we will try again.
-      }
-      catch(const ExceptionConnection& ex)
-      {
-#else
-      std::auto_ptr<ExceptionConnection> error;
-      sharedptr<SharedConnection> sharedconnection = m_pDialogConnection->connect_to_server_with_connection_settings(error);
-      if(error.get())
-      {
-        const ExceptionConnection& ex = *error;
-#endif
-        //g_warning("Frame_Glom::connection_request_password_and_choose_new_database_name(): caught exception.");
-
-        if(ex.get_failure_type() == ExceptionConnection::FAILURE_NO_SERVER)
-        {
-          //Warn the user, and let him try again:
-          Utils::show_ok_dialog(_("Connection Failed"), _("Glom could not connect to the database server. Maybe you entered an incorrect user name or password, or maybe the postgres database server is not running."), *(get_app_window()), Gtk::MESSAGE_ERROR); //TODO: Add help button.
-	  return false;
-        }
-        else
-        {
-          std::cout << "Frame_Glom::connection_request_password_and_choose_new_database_name(): unused database name successfully found: " << database_name_possible << std::endl; 
-          //The connection to the server is OK, but the specified database does not exist.
-          //That's good - we were looking for an unused database name.
-          Document_Glom* document = get_document();
-          if(document)
-          {
-            std::cout << "debug: unused database name found: " << database_name_possible << std::endl;
-            document->set_connection_database(database_name_possible);
-
-            ConnectionPool* connection_pool = ConnectionPool::get_instance();
-            if(connection_pool)
-              document->set_connection_server(connection_pool->get_host());
-          }
-
-          return true;
-        }
-      }
+      // We are not self-hosting, but we also call initialize() for
+      // consistency (the backend will ignore it anyway).
+      if(!connection_pool->initialize(get_app_window()))
+        return false;
+    }
+    else
+    {
+      // The user cancelled
+      return false;
     }
   }
   else
-    return false; //The user cancelled.
+  {
+    // sqlite
+    if(!connection_pool->initialize(get_app_window()))
+      return false;
 
+    m_pDialogConnection->load_from_document(); //Get good defaults.
+    // No authentication required
+  }
+
+  // Do startup, such as starting the self-hosting database server
+  if(!connection_pool->startup(get_app_window()))
+    return false;
+
+  const Glib::ustring database_name = document->get_connection_database();
+
+  //std::cout << "debug: database_name to create=" << database_name << std::endl;
+
+
+  bool keep_trying = true;
+  size_t extra_num = 0;
+  while(keep_trying)
+  {
+    Glib::ustring database_name_possible;
+    if(extra_num == 0)
+      database_name_possible = database_name; //Try the original name first.
+    else
+    {
+      //Create a new database name by appending a number to the original name:
+      Glib::ustring pchExtraNum = Glib::ustring::compose("%1", extra_num);
+      database_name_possible = (database_name + pchExtraNum);
+    }
+    ++extra_num;
+
+    m_pDialogConnection->set_database_name(database_name_possible);
+    //std::cout << "debug: possible name=" << database_name_possible << std::endl;
+
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+    try
+    {
+      sharedptr<SharedConnection> sharedconnection = m_pDialogConnection->connect_to_server_with_connection_settings();
+      //If no exception was thrown then the database exists.
+      //But we are looking for an unused database name, so we will try again.
+    }
+    catch(const ExceptionConnection& ex)
+    {
+#else
+    std::auto_ptr<ExceptionConnection> error;
+    sharedptr<SharedConnection> sharedconnection = m_pDialogConnection->connect_to_server_with_connection_settings(error);
+    if(error.get())
+    {
+      const ExceptionConnection& ex = *error;
+#endif
+      //g_warning("Frame_Glom::connection_request_password_and_choose_new_database_name(): caught exception.");
+
+      if(ex.get_failure_type() == ExceptionConnection::FAILURE_NO_SERVER)
+      {
+        //Warn the user, and let him try again:
+        Utils::show_ok_dialog(_("Connection Failed"), _("Glom could not connect to the database server. Maybe you entered an incorrect user name or password, or maybe the postgres database server is not running."), *(get_app_window()), Gtk::MESSAGE_ERROR); //TODO: Add help button.
+        keep_trying = false;
+      }
+      else
+      {
+        std::cout << "Frame_Glom::connection_request_password_and_choose_new_database_name(): unused database name successfully found: " << database_name_possible << std::endl; 
+        //The connection to the server is OK, but the specified database does not exist.
+        //That's good - we were looking for an unused database name.
+
+        std::cout << "debug: unused database name found: " << database_name_possible << std::endl;
+        document->set_connection_database(database_name_possible);
+
+        // Remember host if the document is not self hosted
+        if(document->get_hosting_mode() == Document_Glom::POSTGRES_CENTRAL_HOSTED)
+        {
+          ConnectionPoolBackend* backend = connection_pool->get_backend();
+          ConnectionPoolBackends::PostgresCentralHosted* central = dynamic_cast<ConnectionPoolBackends::PostgresCentralHosted*>(backend);
+          g_assert(central != NULL);
+
+          document->set_connection_server(central->get_host());
+        }
+
+        return true;
+      }
+    }
+  }
+
+  connection_pool->cleanup(get_app_window());
   return false;
 }
 
@@ -1777,12 +1811,21 @@ bool Frame_Glom::connection_request_password_and_attempt(const Glib::ustring kno
 bool Frame_Glom::connection_request_password_and_attempt(const Glib::ustring known_username, const Glib::ustring& known_password, std::auto_ptr<ExceptionConnection>& error)
 #endif
 {
+  Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
+  if(!document)
+    return false;
+
   if(!m_pDialogConnection)
   {
     Utils::get_glade_widget_derived_with_warning("dialog_connection", m_pDialogConnection);
     add_view(m_pDialogConnection); //Also a composite view.
   }
 
+  ConnectionPool* connection_pool = ConnectionPool::get_instance();
+  setup_connection_pool_from_document(document);
+  if(!connection_pool->startup(get_app_window()))
+    return false;
+
   while(true) //Loop until a return
   {
     //Ask for connection details:
@@ -1797,7 +1840,12 @@ bool Frame_Glom::connection_request_password_and_attempt(const Glib::ustring kno
 
     //Only show the dialog if we don't know the correct username/password yet:
     int response = Gtk::RESPONSE_OK;
-    if(known_username.empty() && known_password.empty())
+    // Don't ask for user/password for sqlite databases, since sqlite does
+    // not support authentication. I'd prefer to get that information from
+    // libgda, but gda_connection_supports_feature() requires a GdaConnection
+    // which we don't have at this point.
+    if(document->get_hosting_mode() != Document_Glom::SQLITE_HOSTED &&
+       known_username.empty() && known_password.empty())
     {
        response = Glom::Utils::dialog_run_with_help(m_pDialogConnection, "dialog_connection");
        m_pDialogConnection->hide();
@@ -1810,7 +1858,7 @@ bool Frame_Glom::connection_request_password_and_attempt(const Glib::ustring kno
       {
         //TODO: Remove any previous database setting?
         sharedptr<SharedConnection> sharedconnection = m_pDialogConnection->connect_to_server_with_connection_settings();
-        return true; //Succeeeded, because no exception was thrown.
+        return true; //Succeeded, because no exception was thrown.
       }
       catch(const ExceptionConnection& ex)
       {
@@ -1833,17 +1881,22 @@ bool Frame_Glom::connection_request_password_and_attempt(const Glib::ustring kno
           response = Glom::Utils::dialog_run_with_help(m_pDialogConnection, "dialog_connection");
           m_pDialogConnection->hide();
           if(response != Gtk::RESPONSE_OK)
+          {
+            connection_pool->cleanup(get_app_window());
             return false; //The user cancelled.
+          }
         }
         else
         {
           g_warning("Frame_Glom::connection_request_password_and_attempt(): rethrowing exception.");
 
+          connection_pool->cleanup(get_app_window());
+
           //The connection to the server is OK, but the specified database does not exist:
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
           throw ex; //Pass it on for the caller to handle.
 #else
-	  error = local_error; //Pass it on for the caller to handle.
+          error = local_error; //Pass it on for the caller to handle.
 #endif
           return false;
         }
@@ -1852,7 +1905,10 @@ bool Frame_Glom::connection_request_password_and_attempt(const Glib::ustring kno
       //Try again.
     }
     else
+    {
+      connection_pool->cleanup(get_app_window());
       return false; //The user cancelled.
+    }
   }
 }
 
