@@ -73,7 +73,7 @@ std::string locate_help_file(const std::string& path, const std::string& doc_nam
     /* This has to be a valid language AND a language with
      * no encoding postfix.  The language will come up without
      * encoding next. */
-    if (lang == NULL || strchr(lang, '.') != NULL)
+    if(lang == NULL || strchr(lang, '.') != NULL)
       continue;
 
     const char* exts[] = { "", ".xml", ".docbook", ".sgml", ".html", NULL };
@@ -423,6 +423,7 @@ Glib::ustring Utils::build_sql_select_with_key(const Glib::ustring& table_name,
 {
   if(!Conversions::value_is_empty(key_value)) //If there is a record to show:
   {
+    //TODO: Use a SQL parameter instead of using sql():
     const Glib::ustring where_clause = "\"" + table_name + "\".\"" + key_field->get_name() + "\" = " + key_field->sql(key_value);
     return Utils::build_sql_select_with_where_clause(table_name, fieldsToGet, where_clause);
   }
@@ -472,10 +473,10 @@ Utils::type_list_values_with_second Utils::get_choice_values(const sharedptr<con
 
   //std::cout << "get_choice_values: Executing SQL: " << sql_query << std::endl;
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
-  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = connection->get_gda_connection()->execute_select_command(sql_query);
+  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = connection->get_gda_connection()->statement_execute_select(sql_query);
 #else
   std::auto_ptr<Glib::Error> error;
-  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = connection->get_gda_connection()->execute_select_command(sql_query, error);
+  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = connection->get_gda_connection()->statement_execute_select(sql_query, error);
 #endif
 
   if(datamodel)
@@ -843,7 +844,7 @@ void Utils::show_help(const Glib::ustring& id)
 #ifndef GLOM_ENABLE_MAEMO
   GError* err = 0;
   const gchar* pId;
-  if (id.length())
+  if(id.length())
   {
     pId = id.c_str();
   }
@@ -883,8 +884,7 @@ void Utils::show_help(const Glib::ustring& id)
 #endif
 }
 
-
-void Utils::show_ok_dialog(const Glib::ustring& title, const Glib::ustring& message, Gtk::Window& parent, Gtk::MessageType message_type)
+void Utils::show_ok_dialog(const Glib::ustring& title, const Glib::ustring& message, Gtk::Window* parent, Gtk::MessageType message_type)
 {
 #ifdef GLOM_ENABLE_MAEMO
   // TODO_maemo: Map message_type to a senseful stock_id?
@@ -892,11 +892,18 @@ void Utils::show_ok_dialog(const Glib::ustring& title, const Glib::ustring& mess
 #else
   Gtk::MessageDialog dialog("<b>" + title + "</b>", true /* markup */, message_type, Gtk::BUTTONS_OK);
   dialog.set_secondary_text(message);
-  dialog.set_transient_for(parent);
+  if(parent)
+    dialog.set_transient_for(*parent);
 #endif
+
   dialog.run();
 }
 
+void Utils::show_ok_dialog(const Glib::ustring& title, const Glib::ustring& message, Gtk::Window& parent, Gtk::MessageType message_type)
+{
+  show_ok_dialog(title, message, &parent, message_type);
+}
+
 namespace
 {
 
