@@ -103,7 +103,11 @@ void Box_DB_Table_Definition::fill_field_row(const Gtk::TreeModel::iterator& ite
   m_AddDel.set_value(iter, m_colTitle, title);
 
   //Type:
-  Field::glom_field_type fieldType = Field::get_glom_type_for_gda_type(field->get_field_info()->get_g_type()); //Could be TYPE_INVALID if the gda type is not one of ours.
+  //Field::glom_field_type fieldType = Field::get_glom_type_for_gda_type(field->get_field_info()->get_g_type()); //Could be TYPE_INVALID if the gda type is not one of ours.
+  // TODO: Why was this done by converting the field's gtype to a glom type
+  // instead of using the glom type directly? This breaks numerical types in
+  // sqlite which we store as double.
+  Field::glom_field_type fieldType = field->get_glom_type();
 
   const Glib::ustring strType = Field::get_type_name_ui( fieldType );
   m_AddDel.set_value(iter, m_colType, strType);
@@ -189,7 +193,21 @@ void Box_DB_Table_Definition::on_adddel_add(const Gtk::TreeModel::iterator& row)
       fill_field_row(row, field);
 
       //Store the generated title in the document:
-      on_adddel_changed(row, m_colTitle);
+      //on_adddel_changed(row, m_colTitle);
+
+      // Don't call on_adddel_changed for this, since this does a lot of
+      // unnecessary extra stuff just to get the field added into the
+      // document:
+
+      Document_Glom* pDoc = static_cast<Document_Glom*>(get_document());
+      if(pDoc)
+      {
+        Document_Glom::type_vecFields vecFields = pDoc->get_table_fields(m_table_name);
+        vecFields.push_back(field);
+        pDoc->set_table_fields(m_table_name, vecFields);
+      }
+
+      m_AddDel.select_item(field->get_name(), m_colName, false);
 
       //m_AddDel.select_item(row, m_colTitle, true); //Start editing the title
     }
@@ -251,7 +269,7 @@ bool Box_DB_Table_Definition::check_field_change(const sharedptr<const Field>& f
 
   //If we are changing a non-glom type:
   //Refuse to edit field definitions that were not created by glom:
-  if(Field::get_glom_type_for_gda_type( field_old->get_field_info()->get_g_type() )  == Field::TYPE_INVALID)
+  if(field_old->get_glom_type() == Field::TYPE_INVALID)
   {
     Utils::show_ok_dialog(_("Invalid database structure"),
       _("This database field was created or edited outside of Glom. It has a data type that is not supported by Glom. Your system administrator may be able to correct this."), parent_window, Gtk::MESSAGE_ERROR);
@@ -604,7 +622,7 @@ bool Box_DB_Table_Definition::field_has_null_values(const sharedptr<const Field>
   //std::cout << "sql_query: " << sql_query << std::endl;
 
   long null_count = 0;
-  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute_select(sql_query, get_app_window());
+  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute_select(sql_query);
   if(datamodel && datamodel->get_n_rows() && datamodel->get_n_columns())
   {
     null_count = datamodel->get_n_rows();
@@ -626,7 +644,7 @@ bool Box_DB_Table_Definition::field_has_non_unique_values(const sharedptr<const
   //Count the distint rows:
   const Glib::ustring sql_query_distinct = "SELECT DISTINCT \"" + field->get_name() + "\" FROM \"" + m_table_name + "\"";
   
-  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute_select(sql_query_distinct, get_app_window());
+  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute_select(sql_query_distinct);
   if(datamodel)
   {
     count_distinct = datamodel->get_n_rows();
@@ -640,7 +658,7 @@ bool Box_DB_Table_Definition::field_has_non_unique_values(const sharedptr<const
   //Count all rows, to compare. TODO_performance: Is there a more efficient way to do this? Maybe count(*), which apparently doesn't ignore NULL rows like count(somefield) would.
   const Glib::ustring sql_query_all = "SELECT \"" + field->get_name() + "\" FROM \"" + m_table_name + "\"";
   
-  datamodel = query_execute_select(sql_query_all, get_app_window());
+  datamodel = query_execute_select(sql_query_all);
   if(datamodel)
   {
     count_all = datamodel->get_n_rows();
