@@ -44,10 +44,6 @@ Dialog_GroupsList::Dialog_GroupsList(BaseObjectType* cobject, const Glib::RefPtr
   refGlade->get_widget("treeview_groups", m_treeview_groups);
   refGlade->get_widget("treeview_tables", m_treeview_tables);
 
-  m_treeview_groups->set_reorderable();
-  m_treeview_groups->enable_model_drag_source();
-  m_treeview_groups->enable_model_drag_dest();
-
   m_model_groups = Gtk::ListStore::create(m_model_columns_groups);
   m_model_tables = Gtk::ListStore::create(m_model_columns_tables);
 
@@ -129,7 +125,7 @@ void Dialog_GroupsList::set_document(const Glib::ustring& layout, Document_Glom*
     m_label_table_name->set_text(table_name);
     m_entry_table_title->set_text( document->get_table_title(table_name) );
 
-    Document_Glom::type_list_layout_groups mapGroups = document->get_data_layout_groups_plus_new_fields(layout, m_table_name);
+    Document_Glom::type_list_layout_groups mapGroups = document->get_data_layout_groups_plus_new_fields(layout, m_table_name, m_layout_platform);
 
     //If no information is stored in the document, then start with something:
 
@@ -209,8 +205,8 @@ void Dialog_GroupsList::on_button_group_delete()
     {
       Gtk::TreeModel::Row row = *iter;
 
-      const Glib::ustring user = row[m_model_columns_groups.m_col_name];
-      if(!user.empty())
+      const Glib::ustring group = row[m_model_columns_groups.m_col_name];
+      if(!group.empty())
       {
         //TODO: Prevent deletion of standard groups
         Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Delete Group")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL);
@@ -222,8 +218,10 @@ void Dialog_GroupsList::on_button_group_delete()
 
         if(response == Gtk::RESPONSE_OK)
         {
-          Glib::ustring strQuery = "DROP GROUP " + user;
-          query_execute(strQuery, this);
+          Glib::ustring strQuery = "DROP GROUP \"" + group + "\"";
+          const bool test = query_execute(strQuery);
+          if(!test)
+            std::cerr << "Box_DB_Table_Definition::on_adddel_delete(): DROP GROUP failed." << std::endl;
 
           fill_group_list();
         }
@@ -260,8 +258,10 @@ void Dialog_GroupsList::on_button_group_new()
 
   if(!group_name.empty())
   {
-    Glib::ustring strQuery = "CREATE GROUP " + group_name;
-    Glib::RefPtr<Gnome::Gda::DataModel> data_model = query_execute(strQuery, this);
+    const Glib::ustring strQuery = "CREATE GROUP \"" + group_name + "\"";
+    const bool test = query_execute(strQuery);
+    if(!test)
+      std::cout << "Dialog_GroupsList::on_button_group_new(): CREATE GROUP failed." << std::endl;
 
     //Give the new group some sensible default privileges:
     Privileges priv;
@@ -401,10 +401,10 @@ void Dialog_GroupsList::fill_table_list(const Glib::ustring& group_name)
   Document_Glom* pDocument = get_document();
   if(pDocument)
   {
-     // Make sure that these are in the document,
-     // so that the correct groups will be created if we recreate the database from the document:
-     GroupInfo group_info;
-     group_info.set_name(group_name);
+    // Make sure that these are in the document,
+    // so that the correct groups will be created if we recreate the database from the document:
+    GroupInfo group_info;
+    group_info.set_name(group_name);
 
     Document_Glom::type_listTableInfo table_list = pDocument->get_tables(true /* plus system prefs */);
 
@@ -496,9 +496,11 @@ bool Dialog_GroupsList::set_table_privilege(const Glib::ustring& table_name, con
 
   strQuery += " GROUP \"" + group_name + "\"";
 
-  query_execute(strQuery, this); //TODO: Handle errors.
+  const bool test = query_execute(strQuery); //TODO: Handle errors.
+  if(!test)
+    std::cerr << "Dialog_GroupsList::set_table_privilege(): GRANT/REVOKE failed." << std::endl;
 
-  return true;
+  return test;
 }
 
 void Dialog_GroupsList::on_treeview_tables_toggled_view(const Glib::ustring& path_string)
