@@ -55,11 +55,11 @@ Notebook_Find::~Notebook_Find()
   remove_view(&m_Box_Details);
 }
 
-bool Notebook_Find::init_db_details(const Glib::ustring& table_name)
+bool Notebook_Find::init_db_details(const Glib::ustring& table_name, const Glib::ustring& layout_platform)
 {
-  bool result = m_Box_List.init_db_details(table_name);
+  bool result = m_Box_List.init_db_details(table_name, layout_platform);
 
-  m_Box_Details.init_db_details(table_name);
+  m_Box_Details.init_db_details(table_name, layout_platform);
 
   return result;
 }
